<template>
  <BreezeGuestLayout>
    <PanelAdmin className="panel-inverse">
      <template #panel-body>
        <div class="card mt-5">
          <div class="card-body">
            <div class="row mb-2">
              <div class="col-md-6">
                <div class="form-group">
                  <BreezeLabel for="name" value="Nama Pengadilan" />
                  <BreezeInput
                    id="name"
                    name="name"
                    type="text"
                    v-model="form.name"
                    required
                    autofocus
                    autocomplete="name"
                  />
                </div>
                <div class="form-group">
                  <BreezeLabel
                    for="court_category"
                    value="Kategori Pengadilan"
                  />
                  <Multiselect
                    id="court_category"
                    name="m_court_categories_id"
                    placeholder="Pilih Kategori Pengadilan"
                    v-model="form.m_court_categories_id"
                    :options="state.courtCategoryOptions"
                    class="form-control"
                    searchable
                  />
                </div>
                <div class="form-group">
                  <BreezeLabel
                    for="justice_category"
                    value="Kategori Peradilan"
                  />
                  <Multiselect
                    name="m_justice_categories_id"
                    placeholder="Pilih Kategori Peradilan"
                    v-model="form.m_justice_categories_id"
                    :options="state.justiceCategoryOptions"
                    class="form-control"
                    searchable
                  />
                </div>
              </div>
              <div class="col-md-6">
                <div class="form-group">
                  <BreezeLabel for="court_class" value="Kelas Pengadilan" />
                  <Multiselect
                    name="m_court_class_id"
                    placeholder="Pilih Kelas Pengadilan"
                    v-model="form.m_court_class_id"
                    :options="state.courtClassOptions"
                    class="form-control"
                    searchable
                  />
                </div>
                <div class="form-group">
                  <BreezeLabel for="provinces" value="Propinsi" />
                  <Multiselect
                    name="m_provinces_id"
                    placeholder="Pilih Propinsi"
                    v-model="form.m_provinces_id"
                    :options="state.provinceOptions"
                    class="form-control"
                    searchable
                  />
                </div>
                <div class="form-group">
                  <BreezeLabel for="regencies" value="Kabupaten" />
                  <Multiselect
                    name="m_regencies_id"
                    placeholder="Pilih Kabupaten"
                    v-model="form.m_regencies_id"
                    :options="state.regenciesOptions"
                    class="form-control"
                    searchable
                  />
                </div>
              </div>
            </div>
            <div class="mb-3">
              <div class="flex items-center justify-end mt-4">
                <Link class="btn btn-danger" :href="route('jdih-pengadilan')"
                  ><i class="fas fa-sync"></i>
                  Reset
                </Link>
                &nbsp;
                <Link
                  class="btn btn-success"
                  :href="route('jdih-pengadilan')"
                  :data="{
                    'filter[name]': form.name,
                    'filter[m_court_categories_id]': form.m_court_categories_id,
                    'filter[m_justice_categories_id]':
                      form.m_justice_categories_id,
                    'filter[m_court_class_id]': form.m_court_class_id,
                    'filter[m_provinces_id]': form.provinces,
                    'filter[m_regencies_id]': form.regencies,
                  }"
                  ><i class="fas fa-search"></i>
                  Cari
                </Link>
              </div>
            </div>
            <div class="card border-0 rounded shadow-mb">
              <div class="card-body">
                <table class="table table-bordered table-responsive-sm">
                  <thead class="thead-dark">
                    <tr>
                      <th scope="col" style="text-align: center">#</th>
                      <th scope="col" style="text-align: center">
                        Nama Pengadilan
                      </th>
                      <th scope="col" style="text-align: center">
                        Kategori Pengadilan
                      </th>
                      <th scope="col" style="text-align: center">
                        Kategori Peradilan
                      </th>
                      <th scope="col" style="text-align: center">
                        Kelas Pengadilan
                      </th>
                      <th scope="col" style="text-align: center">Propinsi</th>
                      <th scope="col" style="text-align: center">Kabupaten</th>
                    </tr>
                  </thead>
                  <tbody>
                    <tr v-for="(item, index) in courts.data" :key="index">
                      <th scope="row">{{ index + 1 }}</th>
                      <td style="text-align: center">
                        {{ item.name }}
                      </td>
                      <td style="text-align: center">
                        <div v-if="item.court_category == null">-</div>
                        <div v-else>
                          {{ item.court_category.name }}
                        </div>
                      </td>
                      <td style="text-align: center">
                        <div v-if="item.justice_category == null">-</div>
                        <div v-else>
                          {{ item.justice_category.name }}
                        </div>
                      </td>
                      <td style="text-align: center">
                        <div v-if="item.court_class == null">-</div>
                        <div v-else>
                          {{ item.court_class.name }}
                        </div>
                      </td>
                      <td style="text-align: center">
                        <div v-if="item.provinces == null">-</div>
                        <div v-else>
                          {{ item.provinces.name }}
                        </div>
                      </td>
                      <td style="text-align: center">
                        <div v-if="item.regencies == null">-</div>
                        <div v-else>
                          {{ item.regencies.name }}
                        </div>
                      </td>
                    </tr>
                  </tbody>
                </table>
              </div>
            </div>
            <Pagination :links="courts.links" />
          </div>
        </div>
      </template>
    </PanelAdmin>
  </BreezeGuestLayout>
</template>

<script>
import BreezeGuestLayout from "@/Layouts/Guest_new.vue";
import PanelAdmin from "@/Components/PanelAdmin.vue";
import AdminHead from "@/Components/AdminHead.vue";
import { Head, Link, useForm } from "@inertiajs/inertia-vue3";
import BreezeInput from "@/Components/Input.vue";
import BreezeLabel from "@/Components/Label.vue";
import { defineComponent, onMounted, reactive } from "vue";
import axios from "axios";
import Multiselect from "@vueform/multiselect";
import Pagination from "@/Components/Pagination.vue";

export default defineComponent({
  props: ["courts"],

  components: {
    BreezeGuestLayout,
    PanelAdmin,
    Head,
    AdminHead,
    Link,
    BreezeInput,
    BreezeLabel,
    Multiselect,
    Pagination,
  },

  setup() {
    const form = useForm({
      name: "",
      m_court_categories_id: null,
      m_court_class_id: null,
      m_justice_categories_id: null,
      m_provinces_id: null,
      m_regencies_id: null,
    });

    const state = reactive({
      provinceOptions: [],
      justiceCategoryOptions: [],
      courtCategoryOptions: [],
      courtClassOptions: [],
      regenciesOptions: [],
    });

    const getProvince = async () => {
      const resProvince = await axios.get("/admin/provinces-dropdown");

      state.provinceOptions = resProvince.data;
    };

    const getJusticeCategory = async () => {
      const resJusticeCategory = await axios.get(
        "/admin/justice-categories-dropdown"
      );

      state.justiceCategoryOptions = resJusticeCategory.data;
    };

    const getCourtCategory = async () => {
      const resCourtCategory = await axios.get(
        "/admin/court-categories-dropdown"
      );

      state.courtCategoryOptions = resCourtCategory.data;
    };

    const getCourtClass = async () => {
      const resCourtClass = await axios.get("/admin/court-class-dropdown");

      state.courtClassOptions = resCourtClass.data;
    };

    const getRegencies = async () => {
      const resRegencies = await axios.get("/admin/regencies-dropdown");

      state.regenciesOptions = resRegencies.data;
    };

    function filter() {
      form.post("/admin/court");
    }

    onMounted(() => {
      getProvince();
      getJusticeCategory();
      getCourtCategory();
      getCourtClass();
      getRegencies();
    });

    return { form, state, filter };
  },

  data() {
    return {
      id: null,
    };
  },
  methods: {
    getId(id) {
      this.id = id;
    },
    deleteData() {
      this.$inertia.delete(`/admin/court/${this.id}`);
    },
  },
});
</script>

<style src="@vueform/multiselect/themes/default.css"></style>
